@@ -14,6 +14,7 @@
 #include "dolphintabwidget.h"
 #include "selectionmode/bottombar.h"
 #include <KActionMenu>
+#include <KConfigWatcher>
 #include <KFileItemActions>
 #include <kio/fileundomanager.h>
 #include <kxmlguiwindow.h>
@@ -110,7 +111,7 @@ public:
     KNewFileMenu *newFileMenu() const;
 
     /**
-     * Augments Qt's build-in QMainWindow context menu to add
+     * Augments Qt's built-in QMainWindow context menu to add
      * Dolphin-specific actions, such as "unlock panels".
      */
     QMenu *createPopupMenu() override;
@@ -314,6 +315,20 @@ private Q_SLOTS:
     /** Performs the current undo operation. */
     void undo();
 
+#if KIO_VERSION >= QT_VERSION_CHECK(6, 17, 0)
+    /**
+     * Updates the state of the 'Redo' menu action dependent
+     * on the parameter \a available.
+     */
+    void slotRedoAvailable(bool available);
+
+    /** Sets the text of the 'Redo' menu action to \a text. */
+    void slotRedoTextChanged(const QString &text);
+
+    /** Performs the current redo operation. */
+    void redo();
+#endif
+
     /**
      * Copies all selected items to the clipboard and marks
      * the items as cut.
@@ -680,6 +695,11 @@ private:
      */
     void setupDockWidgets();
 
+    /**
+     * Initializes or re-initializes the KFileItemActions instance.
+     */
+    void setupFileItemActions();
+
     void updateFileAndEditActions();
     void updateViewActions();
     void updateGoActions();
@@ -776,7 +796,8 @@ private:
     DiskSpaceUsageMenu *m_diskSpaceUsageMenu;
 
     QMenu m_searchTools;
-    KFileItemActions m_fileItemActions;
+    KConfigWatcher::Ptr m_serviceMenuConfigWatcher;
+    KFileItemActions *m_fileItemActions = nullptr;
 
     QTimer *m_sessionSaveTimer;
     QFutureWatcher<void> *m_sessionSaveWatcher;
