@@ -96,6 +96,7 @@ void DolphinTabWidget::readProperties(const KConfigGroup &group)
             openNewActivatedTab();
         }
         const QByteArray state = group.readEntry("Tab Data " % QString::number(i), QByteArray());
+        setCurrentIndex(i);
         tabPageAt(i)->restoreState(state);
     }
 
@@ -170,7 +171,9 @@ void DolphinTabWidget::openNewActivatedTab()
 
 void DolphinTabWidget::openNewActivatedTab(const QUrl &primaryUrl, const QUrl &secondaryUrl)
 {
-    openNewTab(primaryUrl, secondaryUrl);
+    DolphinTabPage *tabPage = openNewTab(primaryUrl, secondaryUrl);
+    Q_EMIT activeViewChanged(tabPage->activeViewContainer());
+
     if (GeneralSettings::openNewTabAfterLastTab()) {
         setCurrentIndex(count() - 1);
     } else {
@@ -513,6 +516,7 @@ void DolphinTabWidget::tabRemoved(int index)
     QTabWidget::tabRemoved(index);
 
     Q_EMIT tabCountChanged(count());
+    m_lastViewedTab->setActive(true);
 }
 
 QString DolphinTabWidget::tabName(DolphinTabPage *tabPage) const
@@ -559,6 +563,7 @@ DolphinViewContainer *DolphinTabWidget::activateViewContainerAt(DolphinTabWidget
         return nullptr;
     }
     viewContainer->setActive(true);
+    Q_EMIT activeViewChanged(viewContainer);
     return viewContainer;
 }
 
