@@ -351,7 +351,9 @@ private Q_SLOTS:
     void slotItemsActivated(const KFileItemList &items);
 
     /**
-     * Handles middle click of file. It opens the file passed using the second application associated with the file's mimetype.
+     * Handles middle click of file. It opens the file passed using
+     * the second application associated with the file's mimetype, or
+     * the third if shift modifier is pressed.
      */
     void slotfileMiddleClickActivated(const KFileItem &item);
 
@@ -460,6 +462,12 @@ private:
      */
     QRect preferredSmallStatusBarGeometry();
 
+    /**
+     * Check if a folder can be created at url.
+     * This method supports only local URLs.
+     */
+    bool isTopMostParentFolderWritable(QUrl url);
+
 protected:
     bool eventFilter(QObject *object, QEvent *event) override;
 
@@ -487,6 +495,8 @@ private:
     Admin::Bar *m_adminBar;
     /// An action to switch to the admin protocol. This variable will always be nullptr unless kio-admin was installed. @see Admin::WorkerIntegration.
     QAction *m_authorizeToEnterFolderAction;
+    /// An action to create new folder in case user enters a nonexistent URL in the location bar.
+    QAction *m_createFolderAction;
 
     KMessageWidget *m_messageWidget;
 
